=======================
 API Reference — Units
=======================

When you ask positions to return distances, velocities, or angles,
they return instances of the following classes.

.. currentmodule:: skyfield.units

.. autoclass:: Distance
   :members:

.. autoclass:: Velocity
   :members:

.. autoclass:: Angle
   :members:

